==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fgpg.2.0.1-1.4.2.tar.gz: gpg/modules/gpg_popup_header.php <==
<?php
/**
 * Module Header page
 *
 * @author Brian Peterson
 *
 * $Id: gpg_popup_header.php,v 1.1 2003/11/20 16:56:47 walter Exp $
 */
 
if (!defined (SM_PATH)){
    if (file_exists('./gpg_functions.php')){
        define (SM_PATH , '../../');
    } elseif (file_exists('../gpg_functions.php')){
        define (SM_PATH , '../../../');
    } elseif (file_exists('../plugins/gpg/gpg_functions.php')){
        define (SM_PATH , '../');
    } else echo "unable to define SM_PATH in gpg_module_header.php, exiting abnormally";
}
require_once(SM_PATH.'plugins/gpg/gpg_options_header.php');

/*
 * Function for easily bailing out on malformed requests.
 *
 * @param strign $err   Error String
 * @return void
 *
 */
function gpg_bail($err)
{
    echo '<font color=red><b>'
         . _("There was a problem with your request.")
         . _("Please try again.")
         . '<p><pre>';

//  print_r($err);
    echo '</pre><p></b></font>';
  //exit();
}

// call the main Squirrelmail page header function
//displayPageHeader($color, 'None');
    echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" vlink=\"$color[7]\" alink=\"$color[7]\" $onload>\n\n";


/**
 * set the localization variables
 * Now tell gettext where the locale directory for your plugin is
 * this is in relation to the src/ directory
 */
bindtextdomain('gpg', SM_PATH . 'plugins/gpg/locale');
/* Switch to your plugin domain so your messages get translated */
textdomain('gpg');

if (! isset($err)) $err = array();

echo '<br>';
/**
 * $Log: gpg_popup_header.php,v $
 * Revision 1.1  2003/11/20 16:56:47  walter
 * - solution to SM header in menu popup window
 *
 *
 */
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fgpg-2.1.tar.gz: gpg/modules/gpg_popup_header.php <==
<?php
/**
 * Module Header page
 *
 * @author Brian Peterson
 *
 * $Id: gpg_popup_header.php,v 1.3 2004/01/18 15:18:12 brian Exp $
 */

if (!defined ('SM_PATH')){
    if (file_exists('./gpg_functions.php')){
        define ('SM_PATH' , '../../');
    } elseif (file_exists('../gpg_functions.php')){
        define ('SM_PATH' , '../../../');
    } elseif (file_exists('../plugins/gpg/gpg_functions.php')){
        define ('SM_PATH' , '../');
    } else echo "unable to define SM_PATH in gpg_module_header.php, exiting abnormally";
}
require_once(SM_PATH.'plugins/gpg/gpg_options_header.php');

/*
 * Function for easily bailing out on malformed requests.
 *
 * @param strign $err   Error String
 * @return void
 *
 */
function gpg_bail($err)
{
    echo '<font color=red><b>'
         . _("There was a problem with your request.")
         . _("Please try again.")
         . '<p><pre>';

//  print_r($err);
    echo '</pre><p></b></font>';
  //exit();
}

// call the main Squirrelmail page header function
//displayPageHeader($color, 'None');
    echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" vlink=\"$color[7]\" alink=\"$color[7]\">\n\n";


/**
 * set the localization variables
 * Now tell gettext where the locale directory for your plugin is
 * this is in relation to the src/ directory
 */
bindtextdomain('gpg', SM_PATH . 'plugins/gpg/locale');
/* Switch to your plugin domain so your messages get translated */
textdomain('gpg');

if (! isset($err)) $err = array();

echo '<br>';
/**
 * $Log: gpg_popup_header.php,v $
 * Revision 1.3  2004/01/18 15:18:12  brian
 * - removed unused $onload declaration to fix E_ALL notice
 *
 * Revision 1.2  2004/01/09 18:27:15  brian
 * changed SM_PATH defines to use quoted string for E_ALL
 *
 * Revision 1.1  2003/11/20 16:56:47  walter
 * - solution to SM header in menu popup window
 *
 *
 */
?>
